@@ -56,7 +56,7 @@ class DmPool(BaseConnectionPool):
         autocommit = params.pop("autocommit", True)
         pool = pooled_db.PooledDB(creator=dmPython, host=self.conn_info.host, port=self.conn_info.port,
                                   user=self.conn_info.user,
-                                  password=self.conn_info.password, db=self.conn_info.db_name,
+                                  password=self.conn_info.password, database=self.conn_info.db_name,
                                   mincached=mincached, blocking=blocking, maxusage=maxusage,
                                   maxshared=maxshared, maxcached=maxcached,
                                   ping=ping, maxconnections=self.conn_info.max_size,
